@@ -29,4 +29,4 @@ from .toggle import (
     PersistentToggle, 
     PersistentAnimatedToggle
 )
-from .toolbar import BaseToolbar, SettingsToolbar
\ No newline at end of file
+from .toolbar import BaseToolbar
\ No newline at end of file
